@@ -552,6 +552,7 @@ typedef enum _MT_LOG_ID
     MT_ERR_CRITICAL_MESSAGE,
     MT_MOS_ALLOCATE_MEMORY,
     MT_MOS_DESTROY_MEMORY,
+    MT_MOS_MEMORY_NINJA_COUNTER,
     MT_LOG_ID_CP_BASE = 0x01000000,
     MT_CP_HAL_NOT_INITIALIZED,
     MT_CP_HAL_FAIL,
@@ -711,8 +712,8 @@ typedef enum _MT_LOG_ID
     MT_VP_USERFEATURE_CTRL,
     MT_VP_FTR_REPORT,
     MT_VP_FEATURE_GRAPH_ID_BASE = 0x02000200,
-    MT_VP_FEATURE_GRAPH_CREATESWFILTERPIPE_START,
-    MT_VP_FEATURE_GRAPH_CREATESWFILTERPIPE_END,
+    MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_START,
+    MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END,
     MT_VP_FEATURE_GRAPH_SETUPEXECUTESWFILTER_START,
     MT_VP_FEATURE_GRAPH_SETUPEXECUTESWFILTER_END,
     MT_VP_FEATURE_GRAPH_EXECUTEFILTER,
@@ -746,6 +747,10 @@ typedef enum _MT_LOG_ID
     MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO,
     MT_VP_FEATURE_GRAPH_SURFACE_ALLOCATIONHANDLE,
     MT_VP_FEATURE_GRAPH_GET_RENDERTARGETTYPE,
+    MT_VP_FEATURE_GRAPH_SWFILTERSR,
+    MT_VP_FEATURE_GRAPH_FEATUREPIPE_REUSE,
+    MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_START,
+    MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_END,
     MT_VP_HAL_ID_BASE = 0x02000400,
     MT_VP_HAL_PIPELINE_ADAPTER,
     MT_VP_HAL_PIPELINE_ADAPTER_EXT_ENTRY,
@@ -870,6 +875,9 @@ typedef enum _MT_PARAM_ID
     MT_MEMORY_PTR,
     MT_MEMORY_SIZE,
     MT_MEMORY_INDEX,
+    MT_MEMORY_NINJA_START_COUNTER,
+    MT_MEMORY_NINJA_END_COUNTER,
+    MT_MEMORY_NINJA_IS_START,
     MT_PARAM_ID_MOS_BASE = 0x00001000,
     MT_MOS_STATUS,
     MT_MOS_GPU_NODE,
@@ -1107,6 +1115,15 @@ typedef enum _MT_PARAM_ID
     MT_VP_FEATURE_GRAPH_SURFACE_RCDST_RIGHT,
     MT_VP_FEATURE_GRAPH_SURFACE_RCDST_BOTTOM,
     MT_VP_FEATURE_GRAPH_RENDERTARGETTYPE,
+    MT_VP_FEATURE_GRAPH_FILTER_ESRMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_SRMODEL,
+    MT_VP_FEATURE_GRAPH_FILTER_SRSTAGE,
+    MT_VP_FEATURE_GRAPH_FILTER_FRAMENUMBER,
+    MT_VP_FEATURE_GRAPH_FILTER_FIRSTFRAME,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLESR,
+    MT_VP_FEATURE_GRAPH_FILTER_FRAMEID,
+    MT_VP_FEATURE_GRAPH_FILTER_PIPEID,
+    MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS,
     MT_PARAM_ID_VP_MHW_BASE = 0x02002000,
     MT_VP_MHW_VE_SCALABILITY_EN,
     MT_VP_MHW_VE_SCALABILITY_USE_SFC,
