@@ -26,6 +26,7 @@
 #include "encode_av1_vdenc_packet_xe_lpm_plus_base.h"
 #include "mos_solo_generic.h"
 #include "encode_av1_superres.h"
+#include "hal_oca_interface_next.h"
 
 namespace encode
 {
@@ -463,6 +464,16 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(&cmdBuffer, tileLevelBatchBuffer));
 
         tempCmdBuffer = &constructTileBatchBuf;
+        MHW_MI_MMIOREGISTERS mmioRegister;
+        if (m_vdencItf->ConvertToMiRegister(MHW_VDBOX_NODE_1, mmioRegister))
+        {
+            HalOcaInterfaceNext::On1stLevelBBStart(
+                *tempCmdBuffer,
+                (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext,
+                m_osInterface->CurrentGpuContextHandle,
+                m_miItf,
+                mmioRegister);
+        }
     }
 
     auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
@@ -476,14 +487,20 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
 
     SETPAR_AND_ADDCMD(AVP_PIPE_BUF_ADDR_STATE, m_avpItf, tempCmdBuffer);
     SETPAR_AND_ADDCMD(AVP_IND_OBJ_BASE_ADDR_STATE, m_avpItf, tempCmdBuffer);
-
+    bool firstTileInGroup = false;
     if (brcFeature->IsBRCEnabled())
     {
-        bool     firstTileInGroup = false;
         uint32_t tileGroupIdx     = 0;
         RUN_FEATURE_INTERFACE_NO_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, IsFirstTileInGroup, firstTileInGroup, tileGroupIdx);
         vdenc2ndLevelBatchBuffer->dwOffset = firstTileInGroup ? slbbData.avpPicStateOffset : slbbData.secondAvpPicStateOffset;
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+        HalOcaInterfaceNext::OnSubLevelBBStart(
+            *tempCmdBuffer,
+            m_osInterface->pOsContext,
+            &vdenc2ndLevelBatchBuffer->OsResource,
+            vdenc2ndLevelBatchBuffer->dwOffset,
+            false,
+            slbbData.slbSize - vdenc2ndLevelBatchBuffer->dwOffset);
     }
     else
     {
@@ -496,6 +513,13 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
     {
         vdenc2ndLevelBatchBuffer->dwOffset = slbbData.avpSegmentStateOffset;
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+        HalOcaInterfaceNext::OnSubLevelBBStart(
+            *tempCmdBuffer,
+            m_osInterface->pOsContext,
+            &vdenc2ndLevelBatchBuffer->OsResource,
+            vdenc2ndLevelBatchBuffer->dwOffset,
+            false,
+            slbbData.vdencCmd1Offset - vdenc2ndLevelBatchBuffer->dwOffset);
     }
     else
     {
@@ -513,6 +537,13 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
     {
         vdenc2ndLevelBatchBuffer->dwOffset = slbbData.vdencCmd1Offset;
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+        HalOcaInterfaceNext::OnSubLevelBBStart(
+            *tempCmdBuffer,
+            m_osInterface->pOsContext,
+            &vdenc2ndLevelBatchBuffer->OsResource,
+            vdenc2ndLevelBatchBuffer->dwOffset,
+            false,
+            slbbData.vdencCmd2Offset - vdenc2ndLevelBatchBuffer->dwOffset);
     }
     else
     {
@@ -525,6 +556,13 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
     {
         vdenc2ndLevelBatchBuffer->dwOffset = slbbData.vdencCmd2Offset;
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+        HalOcaInterfaceNext::OnSubLevelBBStart(
+            *tempCmdBuffer,
+            m_osInterface->pOsContext,
+            &vdenc2ndLevelBatchBuffer->OsResource,
+            vdenc2ndLevelBatchBuffer->dwOffset,
+            false,
+            (firstTileInGroup ? slbbData.avpPicStateOffset : slbbData.secondAvpPicStateOffset) - vdenc2ndLevelBatchBuffer->dwOffset);
     }
     else
     {
@@ -548,6 +586,14 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
         tileLevelBatchBuffer->iCurrent   = constructTileBatchBuf.iOffset;
         tileLevelBatchBuffer->iRemaining = constructTileBatchBuf.iRemaining;
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_END)(nullptr, tileLevelBatchBuffer));
+        HalOcaInterfaceNext::OnSubLevelBBStart(
+            cmdBuffer,
+            m_osInterface->pOsContext,
+            &tempCmdBuffer->OsResource,
+            0,
+            false,
+            tempCmdBuffer->iOffset);
+        HalOcaInterfaceNext::On1stLevelBBEnd(*tempCmdBuffer, *m_osInterface);
     }
 
 #if USE_CODECHAL_DEBUG_TOOL
@@ -827,6 +873,14 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddAllCmds_AVP_PAK_INSERT_OBJECT(PMOS_CO
                     ENCODE_CHK_NULL_RETURN(pakInsertOutputBatchBuffer);
                     // send pak insert obj cmds after back annotation
                     ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(cmdBuffer, pakInsertOutputBatchBuffer));
+                    auto slbbData = brcFeature->GetSLBData();
+                    HalOcaInterfaceNext::OnSubLevelBBStart(
+                        *cmdBuffer,
+                        m_osInterface->pOsContext,
+                        &pakInsertOutputBatchBuffer->OsResource,
+                        pakInsertOutputBatchBuffer->dwOffset,
+                        false,
+                        slbbData.pakInsertSlbSize);
                 }
                 else
                 {
