@@ -508,7 +508,7 @@ MOS_STATUS Mhw_SendGenericPrologCmdNext(
         auto& par = miItf->MHW_GETPAR_F(PIPE_CONTROL)();
         par = {};
         par.dwFlushMode = MHW_FLUSH_WRITE_CACHE;
-        miItf->MHW_ADDCMD_F(PIPE_CONTROL)(pCmdBuffer);
+        MHW_CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(PIPE_CONTROL)(pCmdBuffer));
 
         auto& par1 = miItf->MHW_GETPAR_F(PIPE_CONTROL)();
         par1 = {};
@@ -516,7 +516,7 @@ MOS_STATUS Mhw_SendGenericPrologCmdNext(
         par1.presDest = pParams->presStoreData;
         par1.dwResourceOffset = pParams->dwStoreDataOffset;
         par1.dwPostSyncOp = MHW_FLUSH_WRITE_IMMEDIATE_DATA;
-        miItf->MHW_ADDCMD_F(PIPE_CONTROL)(pCmdBuffer);
+        MHW_CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(PIPE_CONTROL)(pCmdBuffer));
 
         if(pCmdBuffer->Attributes.bUmdSSEUEnable)
         {
