@@ -398,20 +398,30 @@ MOS_STATUS VpPlatformInterface::InitVpCmKernels(
 
     if (!isaFile->readFile())
     {
+        MOS_Delete(isaFile);
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
     vISA::Header *header = isaFile->getHeader();
-    VP_PUBLIC_CHK_NULL_RETURN(header);
+    if(!header)
+    {
+        MOS_Delete(isaFile);
+        VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_NULL_POINTER);
+    }
 
     for (uint32_t i = 0; i < header->getNumKernels(); i++)
     {
         vISA::Kernel *kernel = header->getKernelInfo()[i];
 
-        VP_PUBLIC_CHK_NULL_RETURN(kernel);
+        if(!kernel)
+        {
+            MOS_Delete(isaFile);
+            VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_NULL_POINTER);
+        }
 
         if (kernel->getName() == nullptr || kernel->getNameLen() < 1 || kernel->getNameLen() > 256)
         {
+            MOS_Delete(isaFile);
             VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
         }
 
@@ -438,18 +448,27 @@ MOS_STATUS VpPlatformInterface::InitVpCmKernels(
         vpKernel.SetKernelBinSize(genBinary->getBinarySize());
 
         vISA::KernelBody *kernelBody = isaFile->getKernelsData().at(i);
-        VP_PUBLIC_CHK_NULL_RETURN(kernelBody);
+        if(!kernelBody)
+        {
+            MOS_Delete(isaFile);
+            VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_NULL_POINTER);
+        }
 
         if (kernelBody->getNumInputs() > CM_MAX_ARGS_PER_KERNEL)
         {
-            return MOS_STATUS_INVALID_PARAMETER;
+            MOS_Delete(isaFile);
+            VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
         }
 
         for (uint32_t j = 0; j < kernelBody->getNumInputs(); j++)
         {
             KRN_ARG          kernelArg = {};
             vISA::InputInfo *inputInfo = kernelBody->getInputInfo()[j];
-            VP_PUBLIC_CHK_NULL_RETURN(inputInfo);
+            if (!inputInfo)
+            {
+                MOS_Delete(isaFile);
+                VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_NULL_POINTER);
+            }
             uint8_t          kind      = inputInfo->getKind();
 
             if (kind == 0x2)  // compiler value for surface
@@ -489,7 +508,8 @@ MOS_STATUS VpPlatformInterface::InitVpCmKernels(
                 // IMP_PSEUDO_INPUT = 0x80 is pseudo input. All inputs after this
                 // will be ignored by CMRT without checking and payload copied.
                 // This resizes the argument count to achieve this.
-                return MOS_STATUS_UNIMPLEMENTED;
+                MOS_Delete(isaFile);
+                VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_UNIMPLEMENTED);
             }
 
             kernelArg.uIndex           = j;
